
 # Example 8.1.  The approximate versus approx prices.
 rm(list=ls())

 ##### read data and summary
 SP500 = read.csv("SP500Dividend.csv")
 attach(SP500)
 mean(Yield)              #4.3498
 sd(Yield)                #1.6086
 n = nrow(SP500)
 
 Dates = as.vector(SP500[,1])
 Dates = strptime(Dates, "%m/%d/%Y") #convert to POSIXlt 
						  #(a date class)
 Dates[1:228] = SP500[1:228,1]    #filling wierd NA


 R = c(0, diff(log(Price)))         # monthly returns of SP500
 P = log(Price)                     # log-price
 D = log(Dividend)                  # log-dividend
 P = ts(P, start=c(1881, 1), frequency=12)
 D=  ts(D, start=c(1881, 1), frequency=12)
 yield = ts(Yield, start=c(1881, 1), frequency=12)

 postscript("Fig92.eps", width=4.4, height=4.8, horizontal=F, pointsize=8)
 par(mfrow = c(2,1), mar=c(4,4,4,1)+0.1, cex=0.8)

 plot.ts(P, col=2, lwd=2, xlab="", ylab= "", xaxt="n",yaxt="n")
 lines(D+log(20), col=4)
 title("(a) Price and Dividend")
 labs = c(100,  200, 400, 800, 1600)
 axis(2, at=log(labs), labels=labs)
 labs = c(seq(1880, 2010, by=20), 2010)
 axis(1, at=labs, labels=labs)



 plot.ts(yield, col=4, lwd=2, xlab="", ylab= "Yield")
 #lines(yield, col=4)
 title("(b) Dividend Yields")
 
 dev.off()
 

 ############ getting annual data #############
 
 #Da = 0; Ra = 0                     #Annual dividend and retur
 #for(i in 1:12)
 # { Da = Da + Dividend[i:(n-12+i)]  #Annual dividend
 #   Ra = Ra + R[i:(n-12+i)]
 # }
 # Da = log(Da[seq(1, n, by=12)])
 #Ra = Ra[seq(1, n, by=12)]
 #Ra[1] = Ra[1]*12/11                  #anualized
 #Pa = log(Price[seq(1,n,by=12)])      #Annual log-prices

 ################# compute approximation ###########
 rho = (1 + .0435/12)^{-1}
 k   = -(1 - rho) * log(1-rho)
 approx = k + rho* P + (1-rho)*D - R
 approx = approx[-1]
 P      = P[-n]
 Dates   = Dates[-n]

 

 postscript("Fig93.eps", width=4.4, height=3.0, horizontal=F,
        pointsize=8)
 par(mfrow = c(1,1), mar=c(3,4,4,1)+0.1, cex=0.8)

 plot(Dates, P, type="l", col=2, lwd=2, xlab="",
      ylab="log-price")
 lines(Dates, approx, col=4)
 title("Approximated and exact prices")

 R1 = diff(P)
 Ra = diff(approx)
 mean(R1)    #0.00136
 mean(Ra)    #0.00136
 sd(R1)      #0.04208
 sd(Ra)      #0.04204
 cor(R1, Ra) #0.99999

